@@ -18,7 +18,7 @@ extern "C" {
 #endif
 
 /**
- * XInclude default processing
+ * XInclude default processing.
  */
 void		xsltSetXIncludeDefault	(int xinclude);
 int		xsltGetXIncludeDefault	(void);
@@ -38,7 +38,7 @@ xmlDocPtr		xsltApplyStylesheetUser	(xsltStylesheetPtr style,
 						 FILE * profile,
 					     xsltTransformContextPtr userCtxt);
 /**
- * Private Interfaces
+ * Private Interfaces.
  */
 void		xsltApplyStripSpaces	(xsltTransformContextPtr ctxt,
 					 xmlNodePtr node);
@@ -60,6 +60,14 @@ int		xsltRunStylesheet	(xsltStylesheetPtr style,
 					 const char *output,
 					 xmlSAXHandlerPtr SAX,
 					 xmlOutputBufferPtr IObuf);
+int		xsltRunStylesheetUser	(xsltStylesheetPtr style,
+					 xmlDocPtr doc,
+					 const char **params,
+					 const char *output,
+					 xmlSAXHandlerPtr SAX,
+					 xmlOutputBufferPtr IObuf,
+					 FILE * profile,
+					 xsltTransformContextPtr userCtxt);
 void		xsltApplyOneTemplate	(xsltTransformContextPtr ctxt,
 					 xmlNodePtr node,
 					 xmlNodePtr list,
@@ -134,6 +142,15 @@ void 		xsltForEach		(xsltTransformContextPtr ctxt,
 					 xmlNodePtr inst,
 					 xsltStylePreCompPtr comp);
 void		xsltRegisterAllElement	(xsltTransformContextPtr ctxt);
+
+/*
+ * Hook for the debugger if activated.
+ */
+void		xslHandleDebugger	(xmlNodePtr cur,
+					 xmlNodePtr node,
+					 xsltTemplatePtr templ,
+					 xsltTransformContextPtr ctxt);
+
 #ifdef __cplusplus
 }
 #endif
