@@ -18,21 +18,21 @@ extern "C" {
  *
  * the version string like "1.2.3"
  */
-#define LIBXSLT_DOTTED_VERSION "1.0.22"
+#define LIBXSLT_DOTTED_VERSION "1.0.23"
 
 /**
  * LIBXSLT_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXSLT_VERSION 10022
+#define LIBXSLT_VERSION 10023
 
 /**
  * LIBXSLT_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXSLT_VERSION_STRING "10022"
+#define LIBXSLT_VERSION_STRING "10023"
 
 /**
  * WITH_XSLT_DEBUG:
@@ -45,7 +45,7 @@ extern "C" {
 #define WITH_XSLT_DEBUG
 #endif
 
-#if 0
+#if 1
 /**
  * DEBUG_MEMORY:
  *
@@ -65,6 +65,18 @@ extern "C" {
 #define DEBUG_MEMORY_LOCATION
 #endif
 
+/**
+ * XSLT_NEED_TRIO:
+ *
+ * should be activated in the existing libc library lacks some of the
+ * string formatting function, in that case reuse the Trio ones already
+ * compiled in the libxml2 library.
+ */
+
+#if 0
+#define XSLT_NEED_TRIO
+#endif
+
 /**
  * WITH_XSLT_DEBUGGER:
  *
